@@ -1,12 +1,14 @@
+import importlib
+
 import werkzeug
 from werkzeug.exceptions import HTTPException
 
-_version = werkzeug.__version__.split('.')[0]
+_version = importlib.metadata.version('werkzeug').split('.')[0]
 
 if _version in ('0', '1'):
     class _HTTPException(HTTPException):
         def __init__(self, code, body, headers, response=None):
-            super(_HTTPException, self).__init__(None, response)
+            super().__init__(None, response)
             self.code = code
 
             self.body = body
@@ -20,7 +22,7 @@ if _version in ('0', '1'):
 else:
     class _HTTPException(HTTPException):
         def __init__(self, code, body, headers, response=None):
-            super(_HTTPException, self).__init__(None, response)
+            super().__init__(None, response)
             self.code = code
 
             self.body = body
