@@ -1,8 +1,8 @@
 import authlib
 
-project = u'Authlib'
-copyright = u'&copy; 2017, Hsiaoming Ltd'
-author = u'Hsiaoming Yang'
+project = 'Authlib'
+copyright = '&copy; 2017, Hsiaoming Ltd'
+author = 'Hsiaoming Yang'
 version = authlib.__version__
 release = version
 
@@ -27,7 +27,7 @@ extensions = [
 
 extlinks = {
     'issue': ('https://github.com/lepture/authlib/issues/%s', 'issue #%s'),
-    'PR': ('https://github.com/lepture/authlib/issues/%s', 'pull request #%s'),
+    'PR': ('https://github.com/lepture/authlib/pull/%s', 'pull request #%s'),
 }
 
 intersphinx_mapping = {
@@ -48,7 +48,7 @@ html_theme_options = {
     "twitter_creator": "lepture",
     "twitter_url": "https://twitter.com/authlib",
     "github_url": "https://github.com/lepture/authlib",
-    "discord_url": "https://discord.gg/RNetSNNq",
+    "discord_url": "https://discord.gg/HvBVAeNAaV",
     "nav_links": [
         {
             "title": "Projects",
