@@ -3,7 +3,7 @@ SECRET_KEY = 'django-secret'
 DATABASES = {
     "default": {
         "ENGINE": "django.db.backends.sqlite3",
-        "NAME": "example.sqlite",
+        "NAME": ":memory:",
     }
 }
 
